@@ -25,7 +25,8 @@ class OperationMV(SimpleMV, model=OperationDBM):
         OperationDBM.error_data,
         OperationDBM.extra_data,
 
-        "duration"
+        OperationDBM.duration.fget.__name__,
+        OperationDBM.duration_as_str.fget.__name__
     ]
     column_details_list = [
         OperationDBM.id,
@@ -42,7 +43,8 @@ class OperationMV(SimpleMV, model=OperationDBM):
         OperationDBM.error_data,
         OperationDBM.extra_data,
 
-        "duration"
+        OperationDBM.duration.fget.__name__,
+        OperationDBM.duration_as_str.fget.__name__
     ]
     form_columns = [
         OperationDBM.slug,
@@ -86,7 +88,6 @@ class OperationMV(SimpleMV, model=OperationDBM):
         OperationDBM.output_data: lambda m, a: format_json_for_preview_(m.output_data),
         OperationDBM.error_data: lambda m, a: format_json_for_preview_(m.error_data),
         OperationDBM.extra_data: lambda m, a: format_json_for_preview_(m.extra_data),
-        "duration": lambda m, a: m.duration,
     }
     column_formatters_detail = {
         OperationDBM.creation_dt: lambda m, _: format_datetime_(m.creation_dt),
@@ -94,5 +95,4 @@ class OperationMV(SimpleMV, model=OperationDBM):
         OperationDBM.output_data: lambda m, a: format_json_(m.output_data),
         OperationDBM.error_data: lambda m, a: format_json_(m.error_data),
         OperationDBM.extra_data: lambda m, a: format_json_(m.extra_data),
-        "duration": lambda m, a: m.duration,
     }
